.. :changelog:

History
-------

0.0.1 (04-05-2022)
---------------------

* First code creation


0.1.0 (27-06-2022)
------------------

* First release


1.0.0 (22-09-2022)
------------------

* Add support for environment variables as default argument value
* Arguments with array of values changed from a space separated list to a comma separated list
* CLI now uses the most recent version of the azureenergylabelerlib


1.0.1 (26-09-2022)
------------------

* Fixed a bug preventing collection of resource group findings


1.1.0 (04-10-2022)
------------------

* Updated dependency azurenergylabelerlib to version 2.0.0


2.0.0 (19-10-2022)
------------------

* Microsoft renamed "Azure Security Benchmark" to "Microsoft cloud security benchmark", changing the interface


2.0.1 (20-10-2022)
------------------

* Fix broken dependecies


2.0.2 (08-03-2023)
------------------

* Bump template and dependencies.


2.0.3 (21-03-2023)
------------------

* Bumped library version which now filters subscriptions based on the tenant_id.
